fetch_stake_table_from_sequencer

Function fetch_stake_table_from_sequencer 

pub async fn fetch_stake_table_from_sequencer(
    sequencer_url: &Url,
    epoch: Option<EpochNumber>,
) -> Result<HSStakeTable<SeqTypes>>
Fetch the stake table from a sequencer node given the epoch number

Does not error, runs until the stake table is provided.